| fm_diameter | R Documentation |
Find an upper bound to the convex hull of a point set or function space
fm_diameter(x, ...)
## S3 method for class 'matrix'
fm_diameter(x, manifold = NULL, ...)
## S3 method for class 'sf'
fm_diameter(x, ...)
## S3 method for class 'sfg'
fm_diameter(x, ...)
## S3 method for class 'sfc'
fm_diameter(x, ...)
## S3 method for class 'fm_lattice_2d'
fm_diameter(x, ...)
## S3 method for class 'fm_mesh_1d'
fm_diameter(x, ...)
## S3 method for class 'fm_mesh_2d'
fm_diameter(x, ...)
## S3 method for class 'fm_segm'
fm_diameter(x, ...)
## S3 method for class 'fm_mesh_3d'
fm_diameter(x, ...)
## S3 method for class 'fm_tensor'
fm_diameter(x, ..., multi = FALSE)
## S3 method for class 'fm_collect'
fm_diameter(x, ..., multi = FALSE)
## S3 method for class 'fm_list'
fm_diameter(x, ...)
x |
A point set as an |
... |
Additional parameters passed on to the submethods. |
manifold |
Character string specifying the manifold type. Default for
|
multi |
logical; For multi-domain spaces (e.g. fm_tensor and
fm_collect), if |
A scalar, upper bound for the diameter of the convex hull of the
point set. For multi-domain spaces (e.g. fm_tensor() and
fm_collect()), a vector of upper bounds for each domain is returned.
fm_diameter(fm_tensor): Returns either a single diameter bound (default), or
a vector of sub-domain bounds; see the multi argument.
fm_diameter(fm_collect): Returns either a single diameter bound (default), or
a vector of sub-domain bounds; see the multi argument.
Finn Lindgren Finn.Lindgren@gmail.com
fm_diameter(matrix(c(0, 1, 1, 0, 0, 0, 1, 1), 4, 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.