| fmesher-deprecated | R Documentation |
Some of these functions still attempt to do their job, but will be removed in a future version.
fm_mesh_components(...)
fm_int_object(...)
fm_nonconvex_hull_inla(
x,
convex = -0.15,
concave = convex,
resolution = 40,
eps = NULL,
eps_rel = NULL,
crs = NULL,
...
)
fm_nonconvex_hull_inla_basic(
x,
convex = -0.15,
resolution = 40,
eps = NULL,
crs = fm_crs(x)
)
... |
Unused. |
x |
A spatial object |
convex |
numeric vector; How much to extend |
concave |
numeric vector; The minimum allowed reentrant curvature.
Default equal to |
resolution |
integer; The internal computation resolution. A warning
will be issued when this needs to be increased for higher accuracy, with
the required resolution stated. For |
eps, eps_rel |
The polygonal curve simplification tolerances used for
simplifying the resulting boundary curve. See |
crs |
Optional crs object for the resulting polygon. Default is
|
fm_nonconvex_hull_inla() returns an fm_segm
object, for compatibility with inla.nonconvex.hull().
fm_mesh_components(): Backwards compatibility for fm_components(), deprecated since
version 0.4.0.9001, disabled since 0.6.0
fm_int_object(): Deprecated function since 0.5.0.9013;
use new_fm_int() instead.
fm_nonconvex_hull_inla():
Legacy method for
INLA::inla.nonconvex.hull().
Use fm_nonconvex_hull() with method = "fm" instead, with
either format = "fm" (for compatibility with code
expecting fm_segm output) or format = "sf".
fm_nonconvex_hull_inla_basic(): Special method fm_nonconvex_hull_fm()
method for concave = 0. Requires splancs::nndistF().
For mesh and curve creation, the fm_rcdt_2d_inla() and fm_mesh_2d_inla()
methods will keep the interface syntax used by the INLA::inla.mesh.create()
and INLA::inla.mesh.2d() functions, respectively, whereas the
fm_rcdt_2d(), fm_mesh_2d(), and fm_nonconvex_hull() interfaces may be
different, and potentially change in the future. From version 0.4.0.9002,
the fm_nonconvex_hull_inla() function is deprecated, in favour of the more
configurable update version of fm_nonconvex_hull().
Finn Lindgren Finn.Lindgren@gmail.com
fm_nonconvex_hull()
Other nonconvex inla legacy support:
fm_segm_contour_helper(),
fm_simplify_helper()
# New preferred method for "fm_segm" output:
fm_nonconvex_hull(cbind(0, 0), convex = 1, format = "fm")
# Deprecated:
suppressWarnings(
fm_nonconvex_hull_inla(cbind(0, 0), convex = 1)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.