fmesher_globe_points: Globe points

View source: R/RcppExports.R

fmesher_globe_pointsR Documentation

Globe points

Description

C++ method, may get a stable R interface as fm_globe_points() in the future.

Create points on a globe

Usage

fmesher_globe_points(globe)

Arguments

globe

integer; the number of edge subdivision segments, 1 or higher.

Value

A matrix of points on a unit radius globe

Examples

fmesher_globe_points(1)

fmesher documentation built on Feb. 19, 2026, 9:07 a.m.