Helper functions for displaying call stack information
Usage
fm_caller_name(which = 0L, override = NULL)
fm_call_stack(start = 0L, end = 0L, with_numbers = TRUE, ...)
fm_try_callstack(expr)Value
fm_caller_name returns a string with the the name of a calling
function
fm_call_stack returns a character vector
fm_try_callstack If successful, returns (invisibly) the value from
the evaluated expression, otherwise an error object with call stack
information attached to the error message.