Find an upper bound to the convex hull of a point set or function space
Usage
fm_diameter(x, ...)
# S3 method for class 'matrix'
fm_diameter(x, manifold = NULL, ...)
# S3 method for class 'sf'
fm_diameter(x, ...)
# S3 method for class 'sfg'
fm_diameter(x, ...)
# S3 method for class 'sfc'
fm_diameter(x, ...)
# S3 method for class 'fm_lattice_2d'
fm_diameter(x, ...)
# S3 method for class 'fm_mesh_1d'
fm_diameter(x, ...)
# S3 method for class 'fm_mesh_2d'
fm_diameter(x, ...)
# S3 method for class 'fm_segm'
fm_diameter(x, ...)
# S3 method for class 'fm_mesh_3d'
fm_diameter(x, ...)
# S3 method for class 'fm_tensor'
fm_diameter(x, ..., multi = FALSE)
# S3 method for class 'fm_collect'
fm_diameter(x, ..., multi = FALSE)
# S3 method for class 'fm_list'
fm_diameter(x, ...)Arguments
- x
A point set as an \(n\times d\) matrix, or an
fm_mesh_2d/1d/sfrelated object.- ...
Additional parameters passed on to the submethods.
- manifold
Character string specifying the manifold type. Default for
matrixinput is to treat the point set with Euclidean \(\mathbb{R}^d\) metrics. Usemanifold="S2"for great circle distances on a sphere centred at the origin.- multi
logical; For multi-domain spaces (e.g. fm_tensor and fm_collect), if
TRUE, return a vector of diameter bounds for each domain. IfFALSE(the default), return a single diameter bound, by taking the maximum of the individual bounds.
Value
A scalar, upper bound for the diameter of the convex hull of the
point set. For multi-domain spaces (e.g. fm_tensor() and
fm_collect()), a vector of upper bounds for each domain is returned.
Methods (by class)
fm_diameter(fm_tensor): Returns either a single diameter bound (default), or a vector of sub-domain bounds; see themultiargument.fm_diameter(fm_collect): Returns either a single diameter bound (default), or a vector of sub-domain bounds; see themultiargument.
Author
Finn Lindgren Finn.Lindgren@gmail.com