Integration methods for spatial samplers on fm_mesh_2d meshes.
fm_int_mesh_2d(samplers, domain, name = NULL, int.args = NULL, ...)fm_int_mesh_2d_NULL(samplers, domain, name = NULL, int.args = NULL, ...)
# S3 method for sf
fm_int_mesh_2d(samplers, domain, name = NULL, int.args = NULL, ...)
# S3 method for sfc_POINT
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for sfc_MULTIPOINT
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for sfc_LINESTRING
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for sfc_MULTILINESTRING
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for sfc_POLYGON
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for sfc_MULTIPOLYGON
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for sfc_GEOMETRY
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
.weight = rep(1, NROW(samplers)),
...
)
# S3 method for Spatial
fm_int_mesh_2d(
samplers,
domain,
name = NULL,
int.args = NULL,
format = NULL,
...
)
A list, sf, or Spatial object with
point coordinate information and additional columns weight and .block
For single domain fm_int methods, an object specifying one
or more subsets of the domain, and optional weighting in a weight
variable. For fm_int.list, a list of sampling definitions, where data
frame elements may contain information for multiple domains, in which case
each row represent a separate tensor product integration subspace.
Functional space specification; single domain or a named list of domains
For single-domain methods, the variable name to use for the integration points. Default 'x'
List of arguments passed to line and integration methods.
method: "stable" (to aggregate integration weights onto mesh nodes)
or "direct" (to construct a within triangle/segment integration scheme
without aggregating onto mesh nodes)
nsub1, nsub2: integers controlling the number of internal integration
points before aggregation. Points per triangle: (nsub2+1)^2.
Points per knot segment: nsub1
Additional arguments passed on to other methods
character; determines the output format, as either "sf"
(default for fm_mesh_2d when the sampler is NULL),
"numeric" (default for fm_mesh_1d), "bary", or "sp".
When NULL, determined by the domain and sampler types.
fm_int_mesh_2d(sf): sf integration
fm_int_mesh_2d(sfc_POINT): sfc_POINT integration
fm_int_mesh_2d(sfc_MULTIPOINT): sfc_MULTIPOINT integration
fm_int_mesh_2d(sfc_LINESTRING): sfc_LINESTRING integration
fm_int_mesh_2d(sfc_MULTILINESTRING): sfc_MULTILINESTRING integration
fm_int_mesh_2d(sfc_POLYGON): sfc_POLYGON integration
fm_int_mesh_2d(sfc_MULTIPOLYGON): sfc_MULTIPOLYGON integration
fm_int_mesh_2d(sfc_GEOMETRY): sfc_GEOMERY integration
fm_int_mesh_2d(Spatial): Spatial integration
fm_int_mesh_2d_NULL(): Full domain integration
str(fm_int_mesh_2d(samplers = NULL, domain = fmexample$mesh))
Run the code above in your browser using DataLab