Usage
fm_sizes(...)
# S3 method for class 'fm_mesh_2d'
fm_sizes(mesh, ..., method = "R")
# S3 method for class 'fm_mesh_3d'
fm_sizes(mesh, ...)Value
A list with elements of simplex size information. For 2D meshes:
faceVector with the area of each triangle
vertexVector with the triangle area apportioned to each vertex
face_edgeA matrix with one row per triangle and 3 columns, with edge lengths for the edge opposing each triangle vertex.
For 3D meshes:
cellVector with the volume of each tetrahedron
vertexVector with the tetrahedron volume apportioned to each vertex
cell_faceA matrix with one row per cell and 4 columns, with triangle areas for the triangle opposing each tetrahedron vertex.
cell_edgeA matrix with one row per cell and 4 columns, with edge lengths for the edge anchored at each vertex, pointing to the next vertex in the internal ordering.
Examples
str(fm_sizes(fmexample$mesh))
#> List of 3
#> $ face : num [1:547] 0.0544 0.0471 0.0559 0.5767 0.2336 ...
#> $ face_edge: num [1:547, 1:3] 0.355 0.308 0.384 1.332 0.779 ...
#> $ vertex : num [1:292] 0.349 0.254 0.144 0.361 0.143 ...