| fm_sizes | R Documentation |
Compute effective sizes of faces/cells and vertices in a mesh
fm_sizes(...)
## S3 method for class 'fm_mesh_2d'
fm_sizes(mesh, ..., method = "R")
## S3 method for class 'fm_mesh_3d'
fm_sizes(mesh, ...)
... |
Passed on to submethods |
mesh |
object of a supported mesh class |
method |
character; "R" or "Rcpp". For "S2" manifolds, the "Rcpp" method is always used. The "R" method is currently faster, due to the cost of building internal data structures in the C++ code. |
A list with elements of simplex size information. For 2D meshes:
faceVector with the area of each triangle
vertexVector with the triangle area apportioned to each vertex
face_edgeA matrix with one row per triangle and 3 columns, with edge lengths for the edge opposing each triangle vertex.
For 3D meshes:
cellVector with the volume of each tetrahedron
vertexVector with the tetrahedron volume apportioned to each vertex
cell_faceA matrix with one row per cell and 4 columns, with triangle areas for the triangle opposing each tetrahedron vertex.
cell_edgeA matrix with one row per cell and 4 columns, with edge lengths for the edge anchored at each vertex, pointing to the next vertex in the internal ordering.
str(fm_sizes(fmexample$mesh))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.