Deprecated functions in fmesher
Source:R/deprecated.R, R/components.R, R/integration.R, and 1 more
fmesher-deprecated.RdSome of these functions still attempt to do their job, but will be removed in a future version.
Usage
fm_mesh_components(...)
fm_int_object(...)
fm_nonconvex_hull_inla(
x,
convex = -0.15,
concave = convex,
resolution = 40,
eps = NULL,
eps_rel = NULL,
crs = NULL,
...
)
fm_nonconvex_hull_inla_basic(
x,
convex = -0.15,
resolution = 40,
eps = NULL,
crs = fm_crs(x)
)Arguments
- ...
Unused.
- x
A spatial object
- convex
numeric vector; How much to extend
- concave
numeric vector; The minimum allowed reentrant curvature. Default equal to
convex- resolution
integer; The internal computation resolution. A warning will be issued when this needs to be increased for higher accuracy, with the required resolution stated. For
method="fm"only.- eps, eps_rel
The polygonal curve simplification tolerances used for simplifying the resulting boundary curve. See
fm_simplify_helper()for details. Formethod="fm"only.- crs
Optional crs object for the resulting polygon. Default is
fm_crs(x)
Value
fm_nonconvex_hull_inla() returns an fm_segm
object, for compatibility with inla.nonconvex.hull().
Functions
fm_mesh_components(): Backwards compatibility forfm_components(), deprecated since version0.4.0.9001, disabled since0.6.0fm_int_object(): Deprecated function since0.5.0.9013; usenew_fm_int()instead.fm_nonconvex_hull_inla():Legacy method for
INLA::inla.nonconvex.hull(). Usefm_nonconvex_hull()withmethod = "fm"instead, with eitherformat = "fm"(for compatibility with code expectingfm_segmoutput) orformat = "sf".fm_nonconvex_hull_inla_basic(): Special methodfm_nonconvex_hull_fm()method forconcave = 0. Requiressplancs::nndistF().
INLA compatibility
For mesh and curve creation, the fm_rcdt_2d_inla() and fm_mesh_2d_inla()
methods will keep the interface syntax used by the INLA::inla.mesh.create()
and INLA::inla.mesh.2d() functions, respectively, whereas the
fm_rcdt_2d(), fm_mesh_2d(), and fm_nonconvex_hull() interfaces may be
different, and potentially change in the future. From version 0.4.0.9002,
the fm_nonconvex_hull_inla() function is deprecated, in favour of the more
configurable update version of fm_nonconvex_hull().
See also
Other nonconvex inla legacy support:
fm_segm_contour_helper(),
fm_simplify_helper()
Author
Finn Lindgren Finn.Lindgren@gmail.com
Examples
# New preferred method for "fm_segm" output:
fm_nonconvex_hull(cbind(0, 0), convex = 1, format = "fm")
#> fm_segm object:
#> 32 boundary edges (1 group: 1)
#> Bounding box = (-0.9992483, 0.9992483) x (-0.9992483, 0.9992483) x (0,0)
# Deprecated:
suppressWarnings(
fm_nonconvex_hull_inla(cbind(0, 0), convex = 1)
)
#> fm_segm object:
#> 32 boundary edges (1 group: 1)
#> Bounding box = (-0.9992483, 0.9992483) x (-0.9992483, 0.9992483) x (0,0)