new_fm_int: Construct integration scheme objects

View source: R/integration.R

new_fm_intR Documentation

Construct integration scheme objects

Description

Constructor method for integration scheme objects, allowing default construction of .block information. Primarily meant for internal use, but can be used to manually create data of the same structure as fm_int() output.

Usage

new_fm_int(
  object,
  blocks = FALSE,
  weight = NULL,
  name = NULL,
  override = FALSE
)

Arguments

object

An object representing integration points; either a data.frame-like object, or a vector/list of coordinates or other location reference objects.

blocks

logical; if TRUE, set per-element .block indices. If FALSE (default), set a common block, 1L.

weight

Optional weight variable; if NULL, all weights are set to 1.

name

character; name of the integration domain.

override

logical; If name is non-NULL and override=TRUE for sf object, the current sf_column is renamed to name.

Value

A tibble or sf/tibble object. May acquire additional class attributes in the future.

See Also

fm_int()

Examples

new_fm_int(1:4, blocks = TRUE, weight = c(1, 2, 1, 3), name = "z")

fmesher documentation built on Feb. 19, 2026, 9:07 a.m.