powered by
Constructor method for integration scheme objects, allowing default construction of .block information. Primarily meant for internal use, but can be used to manually create data of the same structure as fm_int() output.
.block
fm_int()
new_fm_int( object, blocks = FALSE, weight = NULL, name = NULL, override = FALSE )
A tibble or sf/tibble object. May acquire additional class attributes in the future.
An object representing integration points; either a data.frame-like object, or a vector/list of coordinates or other location reference objects.
logical; if TRUE, set per-element .block indices. If FALSE (default), set a common block, 1L.
TRUE
FALSE
1L
Optional weight variable; if NULL, all weights are set to 1.
NULL
character; name of the integration domain.
logical; If name is non-NULL and override=TRUE for sf object, the current sf_column is renamed to name.
name
override=TRUE
sf_column
new_fm_int(1:4, blocks = TRUE, weight = c(1, 2, 1, 3), name = "z")
Run the code above in your browser using DataLab